package com.javaseleniumtemplate.pages;

import com.javaseleniumtemplate.bases.PageBase;
import org.openqa.selenium.By;
import org.testng.Assert;

public class MedidasProcionamentoPage extends PageBase {

    By botaoMenu = By.xpath("//div[@class='bars']");
    By campoPesquisar = By.xpath("//section[@class='zh-container-search-menu']//input[@type='text']");
    By opcaoTelaMedidasPorcionamento = By.xpath("//span[text() = 'Medidas de Porcionamento']");

    By botaoAdicionar = By.xpath("//div[@class=\"zh-footer-center\"]//li[@class=\"zh-ripple-effect\"]");
    By botaoSalvar = By.xpath("//div[@class=\"zh-footer-right\"]");
    By botaoEditar = By.xpath("//li[@data-zh-id=\"17672266051026083065453\"]");
    By botaoExcluir = By.xpath("//li[@data-zh-id=\"1767226605973001703455\"]");
    By botaoSim = By.xpath("//section[@class=\"zh-container-alert\"]//footer[@class=\"zh-footer-alert\"]/button[1]");
    By botaoNao = By.xpath("//section[@class=\"zh-container-alert\"]//footer[@class=\"zh-footer-alert\"]/button[2]");
    By botaoVoltar = By.xpath("//div[@class=\"zh-footer-left\"]");
    By botaoOk = By.xpath("//section[@class=\"zh-container-alert\"]//button[@type=\"submit\"]");
    By botaoCancelar = By.xpath("//div[@class=\"zh-footer-left\"]");

    By mensagemAlerta = By.xpath("//section[@class=\"zh-container-alert\"]//div[@class=\"zh-alert-scroll\"]/p");
    By mensagemExcluirSucesso = By.xpath("//*[@class=\"zh-notification-messages\"]//span[@class=\"notification-message-text\"]");
    By mensagemObrigatorioCodigo = By.xpath("//div[@data-zh-id=\"1767226605933326686443\"]//div[@class=\"zh-validation\"]/span");
    By mensagemObrigatorioNome = By.xpath("//div[@data-zh-id=\"17672266051561897484444\"]//div[@class=\"zh-validation\"]/span");

    By campoCodigo = By.id("CDMEDICASE");
    By campoNome = By.id("NMMEDICASE");
    By codigoMedidaProcionamentoAdicionadaTelaIni = By.xpath("//div[@id=\"grid-17672266051372584218442\"]//div[@class=\"body-content\"]/div[5]/div[1]/span");
    By nomeMedidaProcionamentoAdicionadaTelaIni = By.xpath("//div[@id=\"grid-17672266051372584218442\"]//div[@class=\"body-content\"]/div[5]/div[2]/span");

    public void acessarTela() {
        tempoParaAguardarTelaInicial();
        waitForElement(botaoMenu);
        click(botaoMenu);
        sendKeys(campoPesquisar, "Medidas de Porcionamento");
        click(opcaoTelaMedidasPorcionamento);
    }

    public void adicionarMedida() {
        click(botaoAdicionar);

        sendKeys(campoCodigo, "10");
        sendKeys(campoNome, "COPO AMERICANO");
        click(botaoSalvar);

        String codigo = getText(codigoMedidaProcionamentoAdicionadaTelaIni);
        String nome = getText(nomeMedidaProcionamentoAdicionadaTelaIni);
        Assert.assertEquals(codigo, "00010", "Verificação do código da medida de porcionamento adicionada. O código está sendo conferido na tela inicial");
        Assert.assertEquals(nome, "COPO AMERICANO", "Verificação do nome da medida de porcionamento adicionada. O nome está sendo conferido na tela inicial");
    }

    public void editarMedida() {
        tempo();
        click(codigoMedidaProcionamentoAdicionadaTelaIni);
        click(botaoEditar);

        boolean campoCodigohabilitado = returnIfElementIsEnabled(campoCodigo);
        Assert.assertEquals(campoCodigohabilitado, false, "Verificação se no momento da edição o campo código está habilitado");

        clearAndSendKeys(campoNome, "COPO DE REQUEIJÃO");
        click(botaoSalvar);

        String codigo = getText(codigoMedidaProcionamentoAdicionadaTelaIni);
        String nome = getText(nomeMedidaProcionamentoAdicionadaTelaIni);
        Assert.assertEquals(codigo, "00010", "Verificação do código da medida de porcionamento editada. O código está sendo conferido na tela inicial");
        Assert.assertEquals(nome, "COPO DE REQUEIJÃO", "Verificação do nome da medida de porcionamento editada. O nome está sendo conferido na tela inicial");
    }

    public void excluirMedidaAdicionada() {
        tempo();
        click(codigoMedidaProcionamentoAdicionadaTelaIni);
        click(botaoExcluir);

        String mensagem = getText(mensagemAlerta);
        Assert.assertEquals(mensagem, "Deletar o(s) registro(s)?", "Verificação da mensagem de alerta exibida após excluir a medida");
        click(botaoSim);

        tempo();
        String mensagemExcluidoSucesso = getText(mensagemExcluirSucesso);
        Assert.assertEquals(mensagemExcluidoSucesso, "Excluído com sucesso.", "Verificação da mensagem de excluído om sucesso, após a exclusão da medida");
    }

    public void cancelarExclusao() {
        tempo();
        click(codigoMedidaProcionamentoAdicionadaTelaIni);
        click(botaoExcluir);

        String mensagem = getText(mensagemAlerta);
        Assert.assertEquals(mensagem, "Deletar o(s) registro(s)?", "Verificação da mensagem de alerta exibida após excluir a medida");
        click(botaoNao);
        click(botaoVoltar);

        String codigo = getText(codigoMedidaProcionamentoAdicionadaTelaIni);
        String nome = getText(nomeMedidaProcionamentoAdicionadaTelaIni);
        Assert.assertEquals(codigo, "00010", "Verificação do código da medida de porcionamento após cancelar a exclusão. O código está sendo conferido na tela inicial");
        Assert.assertEquals(nome, "COPO DE REQUEIJÃO", "Verificação do nome da medida de porcionamento após cancelar a exclusão. O nome está sendo conferido na tela inicial");
    }

    public void verificarCamposObrigatorios() {
        tempo();
        click(botaoAdicionar);
        tempo();
        click(botaoSalvar);

        //mensagem encontradas
        String codigo = getText(mensagemObrigatorioCodigo);
        String nome = getText(mensagemObrigatorioNome);

        String mensagemEsperada = "Campo obrigatório";
        Assert.assertEquals(codigo, mensagemEsperada, "Verificação da mensagem de campo obrigatório, no campo código");
        Assert.assertEquals(nome, mensagemEsperada, "Verificação da mensagem de campo obrigatório, no campo nome");
        click(botaoCancelar);
    }

    public void tentarAddMedidaComCodigoExistente() {
        tempo();
        click(botaoAdicionar);
        sendKeys(campoCodigo, "1");
        sendKeys(campoNome, "COPO AMERICANO");
        click(botaoSalvar);

        String mensagem = getText(mensagemAlerta);
        String mensagemEsperada = "Impossível adicionar. Registro já existe.";
        Assert.assertEquals(mensagem, mensagemEsperada, "Verificação da mensagem exibida na tela após tentar adicionar um porcionamento com código existente");
        click(botaoOk);
        click(botaoCancelar);
    }

}
